@@ -43,6 +43,7 @@ use App::Dochazka::CLI::Commands::Activity qw( activity_all );
 use App::Dochazka::CLI::Commands::Employee qw( 
     employee_list
     employee_profile
+    employee_team
     set_employee_self_sec_id 
     set_employee_other_sec_id 
     set_employee_self_fullname
@@ -99,11 +100,11 @@ App::Dochazka::CLI::CommandMap - Command map
 
 =head1 VERSION
 
-Version 0.193
+Version 0.196
 
 =cut
 
-our $VERSION = '0.193';
+our $VERSION = '0.196';
 
 
 
@@ -293,6 +294,14 @@ our $dispatch_map = {
     "PUT EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
     "POST EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
     "DELETE EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
+    "GET EMPLOYEE EID _NUM _JSON" => \&_method_employee_eid_num_json,
+    "PUT EMPLOYEE EID _NUM _JSON" => \&_method_employee_eid_num_json,
+    "POST EMPLOYEE EID _NUM _JSON" => \&_method_employee_eid_num_json,
+    "DELETE EMPLOYEE EID _NUM _JSON" => \&_method_employee_eid_num_json,
+    "GET EMPLOYEE EID _NUM TEAM" => \&_method_employee_eid_num_team,
+    "PUT EMPLOYEE EID _NUM TEAM" => \&_method_employee_eid_num_team,
+    "POST EMPLOYEE EID _NUM TEAM" => \&_method_employee_eid_num_team,
+    "DELETE EMPLOYEE EID _NUM TEAM" => \&_method_employee_eid_num_team,
     "GET EMPLOYEE LIST" => \&_method_employee_list,
     "PUT EMPLOYEE LIST" => \&_method_employee_list,
     "POST EMPLOYEE LIST" => \&_method_employee_list,
@@ -313,6 +322,14 @@ our $dispatch_map = {
     "PUT EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
     "POST EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
     "DELETE EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
+    "GET EMPLOYEE NICK _TERM _JSON" => \&_method_employee_nick_term_json,
+    "PUT EMPLOYEE NICK _TERM _JSON" => \&_method_employee_nick_term_json,
+    "POST EMPLOYEE NICK _TERM _JSON" => \&_method_employee_nick_term_json,
+    "DELETE EMPLOYEE NICK _TERM _JSON" => \&_method_employee_nick_term_json,
+    "GET EMPLOYEE NICK _TERM TEAM" => \&_method_employee_nick_term_team,
+    "PUT EMPLOYEE NICK _TERM TEAM" => \&_method_employee_nick_term_team,
+    "POST EMPLOYEE NICK _TERM TEAM" => \&_method_employee_nick_term_team,
+    "DELETE EMPLOYEE NICK _TERM TEAM" => \&_method_employee_nick_term_team,
     "GET EMPLOYEE SEARCH" => \&_method_employee_search,
     "PUT EMPLOYEE SEARCH" => \&_method_employee_search,
     "POST EMPLOYEE SEARCH" => \&_method_employee_search,
@@ -329,6 +346,10 @@ our $dispatch_map = {
     "PUT EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
     "POST EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
     "DELETE EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
+    "GET EMPLOYEE TEAM" => \&_method_employee_team,
+    "PUT EMPLOYEE TEAM" => \&_method_employee_team,
+    "POST EMPLOYEE TEAM" => \&_method_employee_team,
+    "DELETE EMPLOYEE TEAM" => \&_method_employee_team,
 
     # Interval commands
     "GET INTERVAL" => \&_method_interval,
@@ -576,6 +597,8 @@ our $dispatch_map = {
     "EMPLOYEE SET PASSWORD" => \&set_employee_self_password,
     "EMPLOYEE_SPEC PASSWORD" => \&set_employee_other_password,
     "EMPLOYEE_SPEC SET PASSWORD" => \&set_employee_other_password,
+    "EMPLOYEE TEAM" => \&employee_team,
+    "EMPLOYEE_SPEC TEAM" => \&employee_team,
 
     # History commands
     "PRIV HISTORY" => \&dump_priv_history,
