@@ -37,7 +37,7 @@ use 5.012;
 use strict;
 use warnings;
 
-use App::CELL qw( $CELL );
+use App::CELL qw( $CELL $log );
 use App::Dochazka::CLI qw( $current_emp $debug_mode );
 use App::Dochazka::CLI::Util qw( 
     determine_employee
@@ -62,11 +62,11 @@ App::Dochazka::CLI::Commands::Employee - Employee commands
 
 =head1 VERSION
 
-Version 0.193
+Version 0.196
 
 =cut
 
-our $VERSION = '0.193';
+our $VERSION = '0.196';
 
 
 
@@ -77,6 +77,7 @@ our $VERSION = '0.193';
 our @EXPORT_OK = qw( 
     employee_list
     employee_profile
+    employee_team
     set_employee_self_sec_id 
     set_employee_other_sec_id
     set_employee_self_fullname 
@@ -161,6 +162,41 @@ sub employee_list {
 }
 
 
+=head3 employee_team
+
+EMPLOYEE TEAM
+
+=cut
+
+sub employee_team {
+    my ( $ts, $th ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::employee_team" );
+
+    # parse test
+    return parse_test( $ts, $th ) if $ts eq 'PARSE_TEST';
+
+    # determine employee
+    my $status = determine_employee( $th->{'EMPLOYEE_SPEC'} );
+    return $status unless $status->ok;
+    my $emp = $status->payload;
+    my $eid = $emp->eid;
+    my $nick = $emp->nick;
+
+    $status = ( $eid == $current_emp->eid )
+        ? send_req( 'GET', "employee/team" )
+        : send_req( 'GET', "employee/eid/$eid/team" );
+    return $status unless $status->ok;
+
+    my $message = "\nList of employees in the team of ->$nick<-\n    ";
+    $message .= ( $status->payload )
+        ? ( join( "\n    ", @{ $status->payload } ) .  "\n" )
+        : "(none)\n";
+
+    return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION',
+        payload => $message);
+}
+
+
 =head3 set_employee_self_sec_id
 
 SET EMPLOYEE SEC_ID _TERM
