@@ -124,13 +124,32 @@ sub _method_employee_eid_json {
     return [ $method, "employee/eid", $th->{_JSON} ];
 }
 
-# $METHOD employee eid $EID [$JSON]
+# $METHOD employee eid $EID
 sub _method_employee_eid_num {
     my ( $ts, $th ) = @_;
     my $method = $ts->[0];
     my $eid = $th->{_NUM};
 
-    return [ $method, "employee/eid/$eid", $th->{_REST} ];
+    return [ $method, "employee/eid/$eid", '' ];
+}
+
+# $METHOD employee eid $EID $JSON
+sub _method_employee_eid_num_json {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+    my $eid = $th->{_NUM};
+    my $json = $th->{_JSON};
+
+    return [ $method, "employee/eid/$eid", $json ];
+}
+
+# $METHOD employee eid $EID team
+sub _method_employee_eid_num_team {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+    my $eid = $th->{_NUM};
+
+    return [ $method, "employee/eid/$eid/team", '' ];
 }
 
 # $METHOD employee list
@@ -166,17 +185,44 @@ sub _method_employee_nick_json {
     return [ $method, "employee/nick", $th->{_JSON} ];
 }
 
-# $METHOD employee nick $nick [$JSON]
+# $METHOD employee nick $NICK
 sub _method_employee_nick_term {
     my ( $ts, $th ) = @_;
     my $method = $ts->[0];
     my $nick = $th->{_TERM};
 
-    return [ $method, "employee/nick/$nick", $th->{_REST} ];
+    return [ $method, "employee/nick/$nick", '' ];
+}
+
+# $METHOD employee nick $nick $JSON
+sub _method_employee_nick_term_json {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+    my $nick = $th->{_TERM};
+    my $json = $th->{_JSON};
+
+    return [ $method, "employee/nick/$nick", $json ];
+}
+
+# $METHOD employee nick $nick team
+sub _method_employee_nick_term_team {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+    my $nick = $th->{_TERM};
+
+    return [ $method, "employee/nick/$nick/team", '' ];
 }
 
 # $METHOD employee search nick $KEY
 #sub _method_employee_search_nick_key {
 #}
 
+# $METHOD employee team
+sub _method_employee_team {
+    my ( $ts, $th ) = @_;
+    my $method = $ts->[0];
+
+    return [ $method, "employee/team", '' ];
+}
+
 1;
