@@ -39,6 +39,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
+use App::Dochazka qw( $t $today $tomorrow $yesterday init_timepiece );
 use App::Dochazka::CLI qw( 
     $current_emp 
     $current_priv 
@@ -58,8 +59,6 @@ use File::ShareDir;
 use Log::Any::Adapter;
 use Params::Validate qw( :all );
 use Scalar::Util qw( looks_like_number );
-use Time::Piece;
-use Time::Seconds;
 use Try::Tiny;
 use Web::MREST::CLI::UserAgent qw( send_req );
 use Web::MREST::Util qw( normalize_filespec );
@@ -75,11 +74,11 @@ App::Dochazka::CLI::Util - Various reusable components
 
 =head1 VERSION
 
-Version 0.193
+Version 0.196
 
 =cut
 
-our $VERSION = '0.193';
+our $VERSION = '0.196';
 
 
 
@@ -88,24 +87,18 @@ our $VERSION = '0.193';
 
 =cut
 
-our ( $t, $today, $yesterday, $tomorrow );
-
 our @EXPORT_OK = qw( 
     authenticate_to_server 
     determine_employee
     lookup_employee 
     init_cli_client
-    init_timepiece
+    init_prompt
     normalize_date
     normalize_time
     parse_test
     refresh_current_emp 
     rest_error 
     truncate_to
-    $t
-    $today
-    $yesterday
-    $tomorrow
 );
 
 
@@ -275,13 +268,16 @@ sub init_cli_client {
     # load core config params and, if sitedir specified, site config params
     # as well
     my %CELL_ARGS = ( debug_mode => 1 );
-    $CELL_ARGS{sitedir} = $sitedir if $sitedir;
+    if ( $sitedir ) {
+        $CELL_ARGS{sitedir} = $sitedir;
+        print "Loading configuration files from $sitedir\n";
+    }
     $status = $CELL->load( %CELL_ARGS );
     die $status->text unless $status->ok;
 
     init_logger(); 
 
-    init_timepiece();
+    init_prompt();
 
     # initialize the LWP::UserAgent object
     Web::MREST::CLI::UserAgent::init_ua();
@@ -305,25 +301,19 @@ sub init_logger {
 }
 
 
-=head2 init_timepiece
+=head2 init_prompt
 
 (Re-)initialize the date/time-related package variables
 
 =cut
 
-sub init_timepiece {
-    #print "Entering " . __PACKAGE__ . "::init_timepiece\n";
-    $t = localtime;
-    $today = $t->ymd;
+sub init_prompt {
+    #print "Entering " . __PACKAGE__ . "::init_prompt\n";
+    init_timepiece();
     $prompt_date = $today unless $prompt_date;
-    $yesterday = ($t - ONE_DAY)->ymd;
-    $tomorrow = ($t + ONE_DAY)->ymd;
-    #$current_year = $t->year;
     ( $prompt_year, $prompt_month, $prompt_day ) = 
         $prompt_date =~ m/^(\d{4,4})-(\d{1,2})-(\d{1,2})/;
-    #( $current_century ) = $current_year =~ m/^(\d{2,2})/;
     ( $prompt_century ) = $prompt_year =~ m/^(\d{2,2})/;
-    #$current_month = $t->mon;
 }
 
 
@@ -393,7 +383,7 @@ sub normalize_date {
     my $nd;          # nd == normalized date
 
     # initialize timepiece so we can do things like $today, $tomorrow, etc.
-    init_timepiece();
+    init_prompt();
 
     # return prompt date if no raw date provided
     unless ( defined( $rd ) and length( $rd ) > 0 ) {
